summaryrefslogtreecommitdiff
path: root/chromium/net/base/cache_type.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/base/cache_type.h')
-rw-r--r--chromium/net/base/cache_type.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/chromium/net/base/cache_type.h b/chromium/net/base/cache_type.h
index 69b5646ece7..06aa826b8fb 100644
--- a/chromium/net/base/cache_type.h
+++ b/chromium/net/base/cache_type.h
@@ -13,7 +13,8 @@ enum CacheType {
MEMORY_CACHE, // Data is stored only in memory.
MEDIA_CACHE, // Optimized to handle media files.
APP_CACHE, // Backing store for an AppCache.
- SHADER_CACHE // Backing store for the GL shader cache.
+ SHADER_CACHE, // Backing store for the GL shader cache.
+ PNACL_CACHE, // Backing store the PNaCl translation cache
};
// The types of disk cache backend, only used at backend instantiation.